@@ -6,7 +6,6 @@
 extern crate anyhow;
 extern crate clap;
 extern crate exitcode;
-extern crate human_panic;
 
 use std::collections::HashMap;
 use std::fs;
@@ -17,16 +16,13 @@ use std::time::Instant;
 
 use anyhow::{anyhow, Context, Result};
 use clap::{App, Arg};
-use human_panic::setup_panic;
 
 mod error;
 mod utils;
 
-const VERSION: &str = "0.3.0";
+const VERSION: &str = "0.3.2";
 
 fn main() -> Result<()> {
-    setup_panic!();
-
     // Define command-line arguments ----------------------------------------
     let matches = App::new("sabreur")
         .version(format!("v{}", VERSION).as_str())
@@ -376,7 +372,7 @@ fn main() -> Result<()> {
                 // Create unknown file
                 let mut unk_path = PathBuf::from("");
                 unk_path.push(output);
-                unk_path.push(format!("{}{}", "unknown.fa", ext));
+                unk_path.push(format!("{}{}", "unknown.fq", ext));
 
                 let future_unk_path = unk_path.clone();
 
