@@ -16,14 +16,11 @@ use crate::error;
 
 // to_niffler_format function
 pub fn to_niffler_format(format: &str) -> Result<niffler::compression::Format> {
-    if format == "gz" {
-        Ok(niffler::compression::Format::Gzip)
-    } else if format == "bz2" {
-        Ok(niffler::compression::Format::Bzip)
-    } else if format == "xz" {
-        Ok(niffler::compression::Format::Lzma)
-    } else {
-        Ok(niffler::compression::Format::No)
+    match format {
+        "gz" => Ok(niffler::compression::Format::Gzip),
+        "bz2" => Ok(niffler::compression::Format::Bzip),
+        "xz" => Ok(niffler::compression::Format::Lzma),
+        _ => Ok(niffler::compression::Format::No),
     }
 }
 
@@ -291,35 +288,32 @@ pub fn se_fa_demux<'a>(
         let mut iter = my_vec.iter();
         let res = iter.find(|&&x| bc_cmp(x, &f_rec.seq()[..bc_len], mismatch));
 
-        match res {
-            Some(i) => {
-                nb_records.entry(i).and_modify(|e| *e += 1).or_insert(1);
-                write_to_fa(
-                    &barcode_data.get(i).unwrap()[0],
-                    compression,
-                    &f_rec,
-                    level,
-                )
-                .with_context(|| {
-                    error::Error::WritingErrorNoFilename {
-                        format: FileType::Fasta,
-                    }
-                })?;
-            }
-            None => {
-                is_unk_empty = false;
-                write_to_fa(
-                    &barcode_data.get(&"XXX".as_bytes()).unwrap()[0],
-                    compression,
-                    &f_rec,
-                    level,
-                )
-                .with_context(|| {
-                    error::Error::WritingErrorNoFilename {
-                        format: FileType::Fasta,
-                    }
-                })?;
-            }
+        if let Some(i) = res {
+            nb_records.entry(i).and_modify(|e| *e += 1).or_insert(1);
+            write_to_fa(
+                &barcode_data.get(i).unwrap()[0],
+                compression,
+                &f_rec,
+                level,
+            )
+            .with_context(|| {
+                error::Error::WritingErrorNoFilename {
+                    format: FileType::Fasta,
+                }
+            })?;
+        } else {
+            is_unk_empty = false;
+            write_to_fa(
+                &barcode_data.get(&"XXX".as_bytes()).unwrap()[0],
+                compression,
+                &f_rec,
+                level,
+            )
+            .with_context(|| {
+                error::Error::WritingErrorNoFilename {
+                    format: FileType::Fasta,
+                }
+            })?;
         }
     }
 
@@ -372,35 +366,32 @@ pub fn se_fq_demux<'a>(
         let mut iter = my_vec.iter();
         let res = iter.find(|&&x| bc_cmp(x, &f_rec.seq()[..bc_len], mismatch));
 
-        match res {
-            Some(i) => {
-                nb_records.entry(i).and_modify(|e| *e += 1).or_insert(1);
-                write_to_fq(
-                    &barcode_data.get(i).unwrap()[0],
-                    compression,
-                    &f_rec,
-                    level,
-                )
-                .with_context(|| {
-                    error::Error::WritingErrorNoFilename {
-                        format: FileType::Fastq,
-                    }
-                })?;
-            }
-            None => {
-                is_unk_empty = false;
-                write_to_fq(
-                    &barcode_data.get(&"XXX".as_bytes()).unwrap()[0],
-                    compression,
-                    &f_rec,
-                    level,
-                )
-                .with_context(|| {
-                    error::Error::WritingErrorNoFilename {
-                        format: FileType::Fastq,
-                    }
-                })?;
-            }
+        if let Some(i) = res {
+            nb_records.entry(i).and_modify(|e| *e += 1).or_insert(1);
+            write_to_fq(
+                &barcode_data.get(i).unwrap()[0],
+                compression,
+                &f_rec,
+                level,
+            )
+            .with_context(|| {
+                error::Error::WritingErrorNoFilename {
+                    format: FileType::Fastq,
+                }
+            })?;
+        } else {
+            is_unk_empty = false;
+            write_to_fq(
+                &barcode_data.get(&"XXX".as_bytes()).unwrap()[0],
+                compression,
+                &f_rec,
+                level,
+            )
+            .with_context(|| {
+                error::Error::WritingErrorNoFilename {
+                    format: FileType::Fastq,
+                }
+            })?;
         }
     }
 
@@ -448,35 +439,32 @@ pub fn pe_fa_demux<'a>(
         let mut iter = my_vec.iter();
         let res = iter.find(|&&x| bc_cmp(x, &f_rec.seq()[..bc_len], mismatch));
 
-        match res {
-            Some(i) => {
-                nb_records.entry(i).and_modify(|e| *e += 1).or_insert(1);
-                write_to_fa(
-                    &barcode_data.get(i).unwrap()[0],
-                    compression,
-                    &f_rec,
-                    level,
-                )
-                .with_context(|| {
-                    error::Error::WritingErrorNoFilename {
-                        format: FileType::Fasta,
-                    }
-                })?;
-            }
-            None => {
-                unk1_empty = "false";
-                write_to_fa(
-                    &barcode_data.get(&"XXX".as_bytes()).unwrap()[0],
-                    compression,
-                    &f_rec,
-                    level,
-                )
-                .with_context(|| {
-                    error::Error::WritingErrorNoFilename {
-                        format: FileType::Fasta,
-                    }
-                })?;
-            }
+        if let Some(i) = res {
+            nb_records.entry(i).and_modify(|e| *e += 1).or_insert(1);
+            write_to_fa(
+                &barcode_data.get(i).unwrap()[0],
+                compression,
+                &f_rec,
+                level,
+            )
+            .with_context(|| {
+                error::Error::WritingErrorNoFilename {
+                    format: FileType::Fasta,
+                }
+            })?;
+        } else {
+            unk1_empty = "false";
+            write_to_fa(
+                &barcode_data.get(&"XXX".as_bytes()).unwrap()[0],
+                compression,
+                &f_rec,
+                level,
+            )
+            .with_context(|| {
+                error::Error::WritingErrorNoFilename {
+                    format: FileType::Fasta,
+                }
+            })?;
         }
     }
 
@@ -484,35 +472,32 @@ pub fn pe_fa_demux<'a>(
         let mut iter = my_vec.iter();
         let res = iter.find(|&&x| bc_cmp(x, &r_rec.seq()[..bc_len], mismatch));
 
-        match res {
-            Some(i) => {
-                nb_records.entry(i).and_modify(|e| *e += 1).or_insert(1);
-                write_to_fa(
-                    &barcode_data.get(i).unwrap()[1],
-                    compression,
-                    &r_rec,
-                    level,
-                )
-                .with_context(|| {
-                    error::Error::WritingErrorNoFilename {
-                        format: FileType::Fasta,
-                    }
-                })?;
-            }
-            None => {
-                unk2_empty = "false";
-                write_to_fa(
-                    &barcode_data.get(&"XXX".as_bytes()).unwrap()[1],
-                    compression,
-                    &r_rec,
-                    level,
-                )
-                .with_context(|| {
-                    error::Error::WritingErrorNoFilename {
-                        format: FileType::Fasta,
-                    }
-                })?;
-            }
+        if let Some(i) = res {
+            nb_records.entry(i).and_modify(|e| *e += 1).or_insert(1);
+            write_to_fa(
+                &barcode_data.get(i).unwrap()[1],
+                compression,
+                &r_rec,
+                level,
+            )
+            .with_context(|| {
+                error::Error::WritingErrorNoFilename {
+                    format: FileType::Fasta,
+                }
+            })?;
+        } else {
+            unk2_empty = "false";
+            write_to_fa(
+                &barcode_data.get(&"XXX".as_bytes()).unwrap()[1],
+                compression,
+                &r_rec,
+                level,
+            )
+            .with_context(|| {
+                error::Error::WritingErrorNoFilename {
+                    format: FileType::Fasta,
+                }
+            })?;
         }
     }
     let final_str = format!("{}{}", unk1_empty, unk2_empty);
@@ -560,35 +545,32 @@ pub fn pe_fq_demux<'a>(
         let mut iter = my_vec.iter();
         let res = iter.find(|&&x| bc_cmp(x, &f_rec.seq()[..bc_len], mismatch));
 
-        match res {
-            Some(i) => {
-                nb_records.entry(i).and_modify(|e| *e += 1).or_insert(1);
-                write_to_fq(
-                    &barcode_data.get(i).unwrap()[0],
-                    compression,
-                    &f_rec,
-                    level,
-                )
-                .with_context(|| {
-                    error::Error::WritingErrorNoFilename {
-                        format: FileType::Fastq,
-                    }
-                })?;
-            }
-            None => {
-                unk1_empty = "false";
-                write_to_fq(
-                    &barcode_data.get(&"XXX".as_bytes()).unwrap()[0],
-                    compression,
-                    &f_rec,
-                    level,
-                )
-                .with_context(|| {
-                    error::Error::WritingErrorNoFilename {
-                        format: FileType::Fastq,
-                    }
-                })?;
-            }
+        if let Some(i) = res {
+            nb_records.entry(i).and_modify(|e| *e += 1).or_insert(1);
+            write_to_fq(
+                &barcode_data.get(i).unwrap()[0],
+                compression,
+                &f_rec,
+                level,
+            )
+            .with_context(|| {
+                error::Error::WritingErrorNoFilename {
+                    format: FileType::Fastq,
+                }
+            })?;
+        } else {
+            unk1_empty = "false";
+            write_to_fq(
+                &barcode_data.get(&"XXX".as_bytes()).unwrap()[0],
+                compression,
+                &f_rec,
+                level,
+            )
+            .with_context(|| {
+                error::Error::WritingErrorNoFilename {
+                    format: FileType::Fastq,
+                }
+            })?;
         }
     }
 
@@ -596,35 +578,32 @@ pub fn pe_fq_demux<'a>(
         let mut iter = my_vec.iter();
         let res = iter.find(|&&x| bc_cmp(x, &r_rec.seq()[..bc_len], mismatch));
 
-        match res {
-            Some(i) => {
-                nb_records.entry(i).and_modify(|e| *e += 1).or_insert(1);
-                write_to_fq(
-                    &barcode_data.get(i).unwrap()[1],
-                    compression,
-                    &r_rec,
-                    level,
-                )
-                .with_context(|| {
-                    error::Error::WritingErrorNoFilename {
-                        format: FileType::Fastq,
-                    }
-                })?;
-            }
-            None => {
-                unk2_empty = "false";
-                write_to_fq(
-                    &barcode_data.get(&"XXX".as_bytes()).unwrap()[1],
-                    compression,
-                    &r_rec,
-                    level,
-                )
-                .with_context(|| {
-                    error::Error::WritingErrorNoFilename {
-                        format: FileType::Fastq,
-                    }
-                })?;
-            }
+        if let Some(i) = res {
+            nb_records.entry(i).and_modify(|e| *e += 1).or_insert(1);
+            write_to_fq(
+                &barcode_data.get(i).unwrap()[1],
+                compression,
+                &r_rec,
+                level,
+            )
+            .with_context(|| {
+                error::Error::WritingErrorNoFilename {
+                    format: FileType::Fastq,
+                }
+            })?;
+        } else {
+            unk2_empty = "false";
+            write_to_fq(
+                &barcode_data.get(&"XXX".as_bytes()).unwrap()[1],
+                compression,
+                &r_rec,
+                level,
+            )
+            .with_context(|| {
+                error::Error::WritingErrorNoFilename {
+                    format: FileType::Fastq,
+                }
+            })?;
         }
     }
 
@@ -715,7 +694,29 @@ mod tests {
             niffler::Level::One,
             &bc_data,
             0,
-            &mut nb_records
+            &mut nb_records,
+        )
+        .is_ok());
+    }
+
+    #[test]
+    fn test_se_fa_demux_trim() {
+        let mut bc_data: Barcode = HashMap::new();
+        let mut nb_records: HashMap<&[u8], i32> = HashMap::new();
+
+        let forward = tempfile::tempfile().expect("Cannot create temp file");
+        let unknown = tempfile::tempfile().expect("Cannot create temp file");
+
+        bc_data.insert(b"ACCGTA", vec![forward]);
+        bc_data.insert(b"XXX", vec![unknown]);
+
+        assert!(se_fa_demux(
+            "tests/test.fa.gz",
+            niffler::compression::Format::Gzip,
+            niffler::Level::One,
+            &bc_data,
+            0,
+            &mut nb_records,
         )
         .is_ok());
     }
@@ -739,7 +740,7 @@ mod tests {
             niffler::Level::One,
             &bc_data,
             1,
-            &mut nb_records
+            &mut nb_records,
         )
         .is_ok());
     }
@@ -763,7 +764,7 @@ mod tests {
             niffler::Level::One,
             &bc_data,
             2,
-            &mut nb_records
+            &mut nb_records,
         )
         .is_ok());
     }
@@ -788,7 +789,7 @@ mod tests {
             niffler::Level::One,
             &bc_data,
             0,
-            &mut nb_records
+            &mut nb_records,
         )
         .is_ok());
     }
@@ -812,7 +813,7 @@ mod tests {
             niffler::Level::One,
             &bc_data,
             1,
-            &mut nb_records
+            &mut nb_records,
         )
         .is_ok());
     }
@@ -836,7 +837,7 @@ mod tests {
             niffler::Level::One,
             &bc_data,
             2,
-            &mut nb_records
+            &mut nb_records,
         )
         .is_ok());
     }
